API
===

This API documentation is generated from the Python code docstrings (we still have to finalize the Sphinx configuration for this documentation to reflect all code documentation).

.. autosummary::
   :toctree: _autosummary
   :recursive:

   sospice
